This is the first VDK packaging that users would install to play around with it.

It packages:

* Plugin for a local database to get started quickly
* Plugin for Big Data database (Presto) to start feeling the full cycle
* Plugin for job management (vdk-control-cli)

See also [Versatile Data Kit Getting Started](https://github.com/vmware/versatile-data-kit/wiki/Getting-Started).
